@@ -2,6 +2,7 @@ from typing import Optional
 
 from django.db import transaction
 from django.db.models import Q
+from rest_framework.exceptions import ValidationError
 
 from caluma.caluma_core.models import BaseModel
 from caluma.caluma_form import models, validators
@@ -21,12 +22,30 @@ class BaseLogic:
 
 
 class SaveAnswerLogic:
+    @classmethod
+    def get_new_answer(cls, data, user, answer):
+        validated_data = cls.pre_save(
+            cls.validate_for_save(data, user, answer=answer, origin=True)
+        )
+
+        if answer is None:
+            answer = cls.create(validated_data, user)
+        else:
+            answer = cls.update(validated_data, answer)
+
+        return cls.post_save(answer)
+
     @staticmethod
     def validate_for_save(
         data: dict, user: BaseUser, answer: models.Answer = None, origin: bool = False
     ) -> dict:
         question = data["question"]
 
+        # Save empty answer by omitting the value property since graphql-core
+        # doesn't allow `null` literals yet
+        if "value" not in data:
+            data["value"] = None
+
         if question.type == models.Question.TYPE_TABLE and not data.get("documents"):
             data["documents"] = models.Document.objects.filter(pk__in=data["value"])
             del data["value"]
@@ -99,9 +118,42 @@ class SaveAnswerLogic:
         return validated_data
 
 
+class SaveDefaultAnswerLogic(SaveAnswerLogic):
+    @staticmethod
+    def validate_for_save(
+        data: dict, user: BaseUser, answer: models.Answer = None, origin: bool = False
+    ) -> dict:
+        if data["question"].type in [
+            models.Question.TYPE_FILE,
+            models.Question.TYPE_STATIC,
+            models.Question.TYPE_DYNAMIC_CHOICE,
+            models.Question.TYPE_DYNAMIC_MULTIPLE_CHOICE,
+        ]:
+            raise ValidationError(
+                f'Can\'t save default_answer for question of type "{data["question"].type}"'
+            )
+
+        data["document"] = None  # send None as document for validation
+        return SaveAnswerLogic.validate_for_save(data, user, answer, origin)
+
+    @staticmethod
+    @transaction.atomic
+    def create(validated_data: dict, user: Optional[BaseUser] = None) -> models.Answer:
+        answer = SaveAnswerLogic.create(validated_data, user)
+        answer.question.default_answer = answer
+        answer.question.save()
+
+        return answer
+
+    @staticmethod
+    @transaction.atomic
+    def update(validated_data, answer):
+        return SaveAnswerLogic.update(validated_data, answer)
+
+
 class SaveDocumentLogic:
     @staticmethod
-    def _set_default_answers_for_form(form, document):
+    def _set_default_answers_for_form(form, document, user):
         """
         Set answers for questions with a default_answer.
 
@@ -118,22 +170,24 @@ class SaveDocumentLogic:
             if question.type == models.Question.TYPE_FORM:
                 if question.sub_form is not None:
                     document = SaveDocumentLogic._set_default_answers_for_form(
-                        question.sub_form, document
+                        question.sub_form, document, user
                     )
                 continue
             answers.append(
-                question.default_answer.copy(document_family=document.family)
+                question.default_answer.copy(document_family=document.family, user=user)
             )
         document.answers.add(*answers)
         return document
 
     @staticmethod
     @transaction.atomic
-    def create(**kwargs):
-        document = BaseLogic.create(models.Document, **kwargs)
+    def create(
+        validated_data: dict, user: Optional[BaseUser] = None
+    ) -> models.Document:
+        document = BaseLogic.create(model=models.Document, user=user, **validated_data)
 
         document = SaveDocumentLogic._set_default_answers_for_form(
-            document.form, document
+            document.form, document, user
         )
         return document
 
