@@ -3,7 +3,7 @@ import uuid
 from django.contrib.postgres.fields import ArrayField, JSONField
 from django.contrib.postgres.indexes import GinIndex
 from django.db import models, transaction
-from django.db.models.signals import post_init
+from django.db.models.signals import post_delete, post_init
 from django.dispatch import receiver
 from localized_fields.fields import LocalizedField, LocalizedTextField
 from simple_history.models import HistoricalRecords
@@ -122,8 +122,8 @@ class Question(core_models.SlugModel):
         models.CharField(max_length=255), blank=True, default=list
     )
 
-    default_answer = models.ForeignKey(
-        "Answer", on_delete=models.CASCADE, related_name="+", null=True, blank=True
+    default_answer = models.OneToOneField(
+        "Answer", on_delete=models.SET_NULL, related_name="+", null=True, blank=True
     )
 
     @property
@@ -176,6 +176,13 @@ class Question(core_models.SlugModel):
         indexes = [GinIndex(fields=["meta"])]
 
 
+@receiver(post_delete, sender=Question)
+def cleanup_default_answer(sender, instance, **kwargs):
+    """Ensure default_answers are cleanedup."""
+    if instance.default_answer is not None:
+        instance.default_answer.delete()
+
+
 class QuestionOption(core_models.NaturalKeyModel):
     question = models.ForeignKey("Question", on_delete=models.CASCADE)
     option = models.ForeignKey("Option", on_delete=models.CASCADE)
@@ -214,7 +221,7 @@ class DocumentManager(models.Manager):
             # import domain logic here, in order to avoid recursive import error
             from .domain_logic import SaveDocumentLogic
 
-            return SaveDocumentLogic.create(form=task.form, user=user)
+            return SaveDocumentLogic.create({"form": task.form}, user=user)
 
 
 class Document(core_models.UUIDModel):
@@ -265,18 +272,25 @@ class Document(core_models.UUIDModel):
         for answer_document in child_documents:
             answer_document.document.set_family(root_doc)
 
-    def copy(self, family=None):
+    def copy(self, family=None, user=None):
         """Create a copy including all its answers."""
 
         new_document = type(self).objects.create(
-            form=self.form, meta=dict(self.meta), source=self, family=family
+            form=self.form,
+            meta=dict(self.meta),
+            source=self,
+            family=family,
+            created_by_user=user.username if user else None,
+            created_by_group=user.group if user else None,
         )
         if not family:
             family = new_document
 
         # copy answers
         for source_answer in self.answers.all():
-            source_answer.copy(document_family=family, to_document=new_document)
+            source_answer.copy(
+                document_family=family, to_document=new_document, user=user
+            )
 
         return new_document
 
@@ -339,7 +353,7 @@ class Answer(core_models.BaseModel):
         super().delete(args, kwargs)
 
     def create_answer_documents(self, documents):
-        family = self.document.family
+        family = getattr(self.document, "family", None)
         document_ids = [document.pk for document in documents]
 
         for sort, document_id in enumerate(reversed(document_ids), start=1):
@@ -364,13 +378,15 @@ class Answer(core_models.BaseModel):
             ans_doc.document.set_family(ans_doc.document)
             ans_doc.delete()
 
-    def copy(self, document_family=None, to_document=None):
+    def copy(self, document_family=None, to_document=None, user=None):
         new_answer = type(self).objects.create(
             question=self.question,
             value=self.value,
             meta=dict(self.meta),
             date=self.date,
             document=to_document,
+            created_by_user=user.username if user else None,
+            created_by_group=user.group if user else None,
         )
 
         if self.question.type == Question.TYPE_FILE:
@@ -379,10 +395,14 @@ class Answer(core_models.BaseModel):
 
         # TableAnswer: copy AnswerDocument too
         for answer_doc in AnswerDocument.objects.filter(answer=self):
-            new_doc = answer_doc.document.copy(family=document_family)
+            new_doc = answer_doc.document.copy(family=document_family, user=user)
 
             AnswerDocument.objects.create(
-                answer=new_answer, document=new_doc, sort=answer_doc.sort
+                answer=new_answer,
+                document=new_doc,
+                sort=answer_doc.sort,
+                created_by_user=user.username if user else None,
+                created_by_group=user.group if user else None,
             )
         return new_answer
 
