@@ -693,72 +693,6 @@ def test_save_table_question(db, snapshot, question, schema_executor):
     snapshot.assert_match(result.data)
 
 
-@pytest.mark.parametrize("question__type", [models.Question.TYPE_TABLE])
-def test_save_table_question_with_default_answer(
-    db,
-    snapshot,
-    question,
-    question_factory,
-    answer,
-    answer_factory,
-    document_factory,
-    schema_executor,
-):
-    row_question = question_factory(type=models.Question.TYPE_TEXT)
-    question.row_form.questions.add(row_question)
-    row_doc = document_factory(form=question.row_form)
-    answer_factory(document=row_doc, question=row_question, value="foo")
-    answer.documents.add(row_doc)
-    question.default_answer = answer
-    question.save()
-
-    query = """
-        mutation SaveTableQuestion($input: SaveTableQuestionInput!) {
-          saveTableQuestion(input: $input) {
-            question {
-              id
-              slug
-              label
-              meta
-              __typename
-              ... on TableQuestion {
-                rowForm {
-                  slug
-                }
-                defaultAnswer {
-                  tableValue: value {
-                    answers {
-                      edges {
-                        node {
-                          ... on StringAnswer {
-                            value
-                          }
-                        }
-                      }
-                    }
-                  }
-                }
-              }
-            }
-            clientMutationId
-          }
-        }
-    """
-
-    inp = {
-        "input": extract_serializer_input_fields(
-            serializers.SaveTableQuestionSerializer, question
-        )
-    }
-
-    question.default_answer = None  # remove default to make sure it gets set correctly
-    question.save()
-
-    result = schema_executor(query, variable_values=inp)
-    assert not result.errors
-    snapshot.assert_match(result.data)
-
-
 @pytest.mark.parametrize("question__type", [models.Question.TYPE_FORM])
 def test_save_form_question(db, snapshot, question, question_option, schema_executor):
     query = """
